Changelog
=========

* :release:`0.3.0 <2015-08-20>`
* :feature:`3` Implement Jug logging (verbose option)
* :feature:`1` Implement keep_going option

* :release:`0.2.0 <2015-08-17>`
* :feature:`0` Rename `gridjug` module to `grid_jug`
* :feature:`0` Implement tests for NLD cluster

* :release:`0.1.0 <2015-08-17>`
* :feature:`0` Basic functionality
